from enum import IntEnum


class ResultCode(IntEnum):
    SUCCESS = 100
    MERCHANT_NOT_FOUND = 102
    MERCHANT_DISABLED = 103
    INVALID_MERCHANT = 104
    AMOUNT_TOO_LOW = 105
    INVALID_CALLBACK_URL = 106
    INVALID_PERCENT_MODE = 107
    INVALID_MULTIPLEX_BENEFICIARY = 108
    INACTIVE_MULTIPLEX_BENEFICIARY = 109
    MISSING_SELF_BENEFICIARY = 110
    MULTIPLEX_AMOUNT_MISMATCH = 111
    WALLET_FEE_BALANCE_TOO_LOW = 112
    AMOUNT_TOO_HIGH = 113
    INVALID_NATIONAL_CODE = 114

    INTERNAL_ERROR = -2
    WAITING_FOR_PAYMENT = -1
